==> bumpster-0.1.6.tar.gz: bumpster-0.1.6/bumpster/git.py <==
# -*- coding: utf-8 -*-

import subprocess
import os


#######################################
#
#   Git Class
#
#######################################


"""
commit message keywords borrowed from python-semantic-release

feat: A new feature. (minor)
fix: A bug fix. (patch)
docs: Documentation changes. (build)
style: Changes that do not affect the meaning of the code 
    (white-space, formatting, missing semi-colons, etc). (build)
refactor: A code change that neither fixes a bug nor adds a feature. (build)
perf: A code change that improves performance. (patch)
test: Changes to the test framework. (build)
build: Changes to the build process or tools. (build)
"""


class Git:
    """
    Simple class to communicate with git via subprocess git commands.
    The other alternative is to use python-git which is big and rarely
    already installed.
    """
    def __init__(self):
        # First we'll initialize some variables
        self.usable = None
        self._root = None
        self.current_version = None
        self.commit_sha = None
        self.distance_to_latest_tag = None
        self.dirty = None

        # Now we can test git, get root_dir, and describe
        self.usable = self.is_usable()
        if self.usable:
            self._root = self.find_root()
            d = self.describe()

    @property
    def root(self):
        if self.usable and self._root:
            return self._root
        return None

    def is_usable(self):
        """
        Simple test to check if git is installed and can
        be used.
        """
        try:
            test = subprocess.call(
                ["git", "rev-parse", "--git-dir"],
                stderr=subprocess.PIPE,
                stdout=subprocess.PIPE,
            )
            return test == 0
        except exception as e:
            return False

    def find_root(self):
        """
        Find the git root
        """
        repo_dir = subprocess.Popen(
            ['git', 'rev-parse', '--show-toplevel'], 
            stdout=subprocess.PIPE
        ).communicate()[0].rstrip().decode('utf-8')
        
        return repo_dir

    def describe(self):
        """
        get info about the latest tag in git
        """
        describe_out = (
            subprocess.check_output(
                [
                    "git",
                    "describe",
                    "--dirty",
                    "--tags",
                    "--long",
                ],
                stderr=subprocess.STDOUT,
            )
            .decode()
            .split("-")
        )
        
        if describe_out[-1].strip() == "dirty":
            self.dirty = True
            describe_out.pop()

        self.commit_sha = describe_out.pop().lstrip("g")
        self.distance_to_latest_tag = int(describe_out.pop())
        self.current_version = "-".join(describe_out).lstrip("v")

        return None

    def add(self, files='.'):
        """
        Wrapper to git add.
        """
        try:
            subprocess.check_output(["git", "add", files])
        except subprocess.CalledProcessError as e:
            print("Exception on process, rc=", e.returncode, "output=", e.output)

    def push(self, tag):
        """
        Wrapper to git add.
        """
        try:
            subprocess.check_output(["git", "push", "origin", "master", tag])
        except subprocess.CalledProcessError as e:
            print("Exception on process, rc=", e.returncode, "output=", e.output)

    def commit(self, message):
        """
        Wrapper to create git commits.
        """
        env = os.environ.copy()
        env["HGENCODING"] = "utf-8"
        try:
            c = subprocess.check_output(
                ["git", "commit", "-v", "-m", message],
                env=env,
                stderr=subprocess.STDOUT
            )
        except subprocess.CalledProcessError as e:
            print("Exception on process, rc=", e.returncode, "output=", e.output)
            raise

    def tag(self, tag_name, sign=False, message=None):
        """
        Create a git tag.
        """
        command = ["git", "tag", "-a", tag_name]
        if sign:
            command += ["--sign"]
        if message:
            command += ["--message", message]
        try:
            subprocess.check_output(command)
        except subprocess.CalledProcessError as e:
            print("Exception on process, rc=", e.returncode, "output=", e.output)

==> bumpster-0.1.11.tar.gz: bumpster-0.1.11/bumpster/git.py <==
# -*- coding: utf-8 -*-

import subprocess
import os


#######################################
#
#   Git Class
#
#######################################


"""
commit message keywords borrowed from python-semantic-release

feat: A new feature. (minor)
fix: A bug fix. (patch)
docs: Documentation changes. (build)
style: Changes that do not affect the meaning of the code 
    (white-space, formatting, missing semi-colons, etc). (build)
refactor: A code change that neither fixes a bug nor adds a feature. (build)
perf: A code change that improves performance. (patch)
test: Changes to the test framework. (build)
build: Changes to the build process or tools. (build)
"""


class Git:
    """
    Simple class to communicate with git via subprocess git commands.
    The other alternative is to use python-git which is big and rarely
    already installed.
    """
    def __init__(self):
        # First we'll initialize some variables
        self.usable = None
        self._root = None
        self.current_version = None
        self.commit_sha = None
        self.distance_to_latest_tag = None
        self.dirty = None

        # Now we can test git, get root_dir, and describe
        self.usable = self.is_usable()
        if self.usable:
            self._root = self.find_root()
            d = self.describe()

    @property
    def root(self):
        if self.usable and self._root:
            return self._root
        return None

    def is_usable(self):
        """
        Simple test to check if git is installed and can
        be used.
        """
        try:
            test = subprocess.call(
                ["git", "rev-parse", "--git-dir"],
                stderr=subprocess.PIPE,
                stdout=subprocess.PIPE,
            )
            return test == 0
        except exception as e:
            return False

    def find_root(self):
        """
        Find the git root
        """
        repo_dir = subprocess.Popen(
            ['git', 'rev-parse', '--show-toplevel'], 
            stdout=subprocess.PIPE
        ).communicate()[0].rstrip().decode('utf-8')
        
        return repo_dir

    def describe(self):
        """
        get info about the latest tag in git
        """
        describe_out = (
            subprocess.check_output(
                [
                    "git",
                    "describe",
                    "--dirty",
                    "--tags",
                    "--long",
                ],
                stderr=subprocess.STDOUT,
            )
            .decode()
            .split("-")
        )
        
        if describe_out[-1].strip() == "dirty":
            self.dirty = True
            describe_out.pop()

        self.commit_sha = describe_out.pop().lstrip("g")
        self.distance_to_latest_tag = int(describe_out.pop())
        self.current_version = "-".join(describe_out).lstrip("v")

        return None

    def add(self, files='.'):
        """
        Wrapper to git add.
        """
        try:
            subprocess.check_output(["git", "add", files])
        except subprocess.CalledProcessError as exc:
            raise RuntimeError(
                f'git commit failed: {exc.cmd} {exc.returncode} {exc.output}')

    def push(self, tag):
        """
        Wrapper to git add.
        """
        try:
            subprocess.check_output(["git", "push", "origin", "master", tag])
        except subprocess.CalledProcessError as exc:
            raise RuntimeError(
                f'git commit failed: {exc.cmd} {exc.returncode} {exc.output}')

    def commit(self, message):
        """
        Wrapper to create git commits.
        """
        try:
            subprocess.check_output(["git", "commit", "-m", message])
        except subprocess.CalledProcessError as exc:
            raise RuntimeError(
                f'git commit failed: {exc.cmd} {exc.returncode} {exc.output}')

    def tag(self, tag_name, sign=False, message=None):
        """
        Create a git tag.
        """
        command = ["git", "tag", "-a", tag_name]
        if sign:
            command += ["--sign"]
        if message:
            command += ["--message", message]
        subprocess.check_output(command)
